@@ -1,5 +1,5 @@
 package Microsoft::AdCenter::ReportingService::DestinationUrlPerformanceReportFilter;
-# Copyright (C) 2011 Xerxes Tsang
+# Copyright (C) 2010 Xerxes Tsang
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of Perl Artistic License.
 
@@ -19,12 +19,11 @@ sub _type_name {
 }
 
 sub _namespace_uri {
-    return 'https://adcenter.microsoft.com/v7';
+    return 'https://adcenter.microsoft.com/v6';
 }
 
 our @_attributes = (qw/
     AdDistribution
-    DeviceType
     LanguageAndRegion
 /);
 
@@ -35,7 +34,6 @@ sub _attributes {
 
 our %_attribute_type = (
     AdDistribution => 'AdDistributionReportFilter',
-    DeviceType => 'DeviceTypeReportFilter',
     LanguageAndRegion => 'LanguageAndRegionReportFilter',
 );
 
@@ -49,7 +47,6 @@ sub _attribute_type {
 
 our %_attribute_min_occurs = (
     AdDistribution => 0,
-    DeviceType => 0,
     LanguageAndRegion => 0,
 );
 
@@ -81,10 +78,6 @@ Creates a new instance
 
 Gets/sets AdDistribution (AdDistributionReportFilter)
 
-=head2 DeviceType
-
-Gets/sets DeviceType (DeviceTypeReportFilter)
-
 =head2 LanguageAndRegion
 
 Gets/sets LanguageAndRegion (LanguageAndRegionReportFilter)
